# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.enums",
    marshal="google.ads.googleads.v19",
    manifest={
        "ShoppingAddProductsToCampaignRecommendationEnum",
    },
)


class ShoppingAddProductsToCampaignRecommendationEnum(proto.Message):
    r"""Indicates the key issue that results in a shopping campaign
    targeting zero products.

    """

    class Reason(proto.Enum):
        r"""Issues that results in a shopping campaign targeting zero
        products.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            MERCHANT_CENTER_ACCOUNT_HAS_NO_SUBMITTED_PRODUCTS (2):
                The Merchant Center account does not have any
                submitted products.
            MERCHANT_CENTER_ACCOUNT_HAS_NO_SUBMITTED_PRODUCTS_IN_FEED (3):
                The Merchant Center account does not have any
                submitted products in the feed.
            ADS_ACCOUNT_EXCLUDES_OFFERS_FROM_CAMPAIGN (4):
                The Google Ads account has active campaign
                filters that prevents inclusion of offers in the
                campaign.
            ALL_PRODUCTS_ARE_EXCLUDED_FROM_CAMPAIGN (5):
                All products available have been explicitly
                excluded from being targeted by the campaign.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        MERCHANT_CENTER_ACCOUNT_HAS_NO_SUBMITTED_PRODUCTS = 2
        MERCHANT_CENTER_ACCOUNT_HAS_NO_SUBMITTED_PRODUCTS_IN_FEED = 3
        ADS_ACCOUNT_EXCLUDES_OFFERS_FROM_CAMPAIGN = 4
        ALL_PRODUCTS_ARE_EXCLUDED_FROM_CAMPAIGN = 5


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v22.enums.types import chain_relationship_type
from google.ads.googleads.v22.enums.types import (
    location_ownership_type as gage_location_ownership_type,
)
from google.ads.googleads.v22.enums.types import location_string_filter_type


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.common",
    marshal="google.ads.googleads.v22",
    manifest={
        "LocationSet",
        "BusinessProfileLocationSet",
        "ChainSet",
        "ChainFilter",
        "MapsLocationSet",
        "MapsLocationInfo",
        "BusinessProfileLocationGroup",
        "DynamicBusinessProfileLocationGroupFilter",
        "BusinessProfileBusinessNameFilter",
        "ChainLocationGroup",
    },
)


class LocationSet(proto.Message):
    r"""Data related to location set. One of the Google Business
    Profile (previously known as Google My Business) data, Chain
    data, and map location data need to be specified.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        location_ownership_type (google.ads.googleads.v22.enums.types.LocationOwnershipTypeEnum.LocationOwnershipType):
            Required. Immutable. Location Ownership Type
            (owned location or affiliate location).
        business_profile_location_set (google.ads.googleads.v22.common.types.BusinessProfileLocationSet):
            Data used to configure a location set
            populated from Google Business Profile
            locations.

            This field is a member of `oneof`_ ``source``.
        chain_location_set (google.ads.googleads.v22.common.types.ChainSet):
            Data used to configure a location on chain
            set populated with the specified chains.

            This field is a member of `oneof`_ ``source``.
        maps_location_set (google.ads.googleads.v22.common.types.MapsLocationSet):
            Only set if locations are synced based on
            selected maps locations

            This field is a member of `oneof`_ ``source``.
    """

    location_ownership_type: (
        gage_location_ownership_type.LocationOwnershipTypeEnum.LocationOwnershipType
    ) = proto.Field(
        proto.ENUM,
        number=3,
        enum=gage_location_ownership_type.LocationOwnershipTypeEnum.LocationOwnershipType,
    )
    business_profile_location_set: "BusinessProfileLocationSet" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="source",
        message="BusinessProfileLocationSet",
    )
    chain_location_set: "ChainSet" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="source",
        message="ChainSet",
    )
    maps_location_set: "MapsLocationSet" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="source",
        message="MapsLocationSet",
    )


class BusinessProfileLocationSet(proto.Message):
    r"""Data used to configure a location set populated from Google
    Business Profile locations.
    Different types of filters are AND'ed together, if they are
    specified.

    Attributes:
        http_authorization_token (str):
            Required. Immutable. The HTTP authorization
            token used to obtain authorization.
        email_address (str):
            Required. Immutable. Email address of a
            Google Business Profile account or email address
            of a manager of the Google Business Profile
            account.
        business_name_filter (str):
            Used to filter Google Business Profile
            listings by business name. If businessNameFilter
            is set, only listings with a matching business
            name are candidates to be sync'd into Assets.
        label_filters (MutableSequence[str]):
            Used to filter Google Business Profile
            listings by labels. If entries exist in
            labelFilters, only listings that have any of the
            labels set are candidates to be synchronized
            into Assets. If no entries exist in
            labelFilters, then all listings are candidates
            for syncing. Label filters are OR'ed together.
        listing_id_filters (MutableSequence[int]):
            Used to filter Google Business Profile
            listings by listing id. If entries exist in
            listingIdFilters, only listings specified by the
            filters are candidates to be synchronized into
            Assets. If no entries exist in listingIdFilters,
            then all listings are candidates for syncing.
            Listing ID filters are OR'ed together.
        business_account_id (str):
            Immutable. The account ID of the managed
            business whose locations are to be used. If this
            field is not set, then all businesses accessible
            by the user (specified by the emailAddress) are
            used.
    """

    http_authorization_token: str = proto.Field(
        proto.STRING,
        number=1,
    )
    email_address: str = proto.Field(
        proto.STRING,
        number=2,
    )
    business_name_filter: str = proto.Field(
        proto.STRING,
        number=3,
    )
    label_filters: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    listing_id_filters: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=5,
    )
    business_account_id: str = proto.Field(
        proto.STRING,
        number=6,
    )


class ChainSet(proto.Message):
    r"""Data used to configure a location set populated with the
    specified chains.

    Attributes:
        relationship_type (google.ads.googleads.v22.enums.types.ChainRelationshipTypeEnum.ChainRelationshipType):
            Required. Immutable. Relationship type the
            specified chains have with this advertiser.
        chains (MutableSequence[google.ads.googleads.v22.common.types.ChainFilter]):
            Required. A list of chain level filters, all
            filters are OR'ed together.
    """

    relationship_type: (
        chain_relationship_type.ChainRelationshipTypeEnum.ChainRelationshipType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=chain_relationship_type.ChainRelationshipTypeEnum.ChainRelationshipType,
    )
    chains: MutableSequence["ChainFilter"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="ChainFilter",
    )


class ChainFilter(proto.Message):
    r"""One chain level filter on location in a feed item set.
    The filtering logic among all the fields is AND.

    Attributes:
        chain_id (int):
            Required. Used to filter chain locations by
            chain id. Only chain locations that belong to
            the specified chain will be in the asset set.
        location_attributes (MutableSequence[str]):
            Used to filter chain locations by location
            attributes. Only chain locations that belong to
            all of the specified attribute(s) will be in the
            asset set. If this field is empty, it means no
            filtering on this field.
    """

    chain_id: int = proto.Field(
        proto.INT64,
        number=1,
    )
    location_attributes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class MapsLocationSet(proto.Message):
    r"""Wrapper for multiple maps location sync data

    Attributes:
        maps_locations (MutableSequence[google.ads.googleads.v22.common.types.MapsLocationInfo]):
            Required. A list of maps location info that
            user manually synced in.
    """

    maps_locations: MutableSequence["MapsLocationInfo"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="MapsLocationInfo",
    )


class MapsLocationInfo(proto.Message):
    r"""Wrapper for place ids

    Attributes:
        place_id (str):
            Place ID of the Maps location.
    """

    place_id: str = proto.Field(
        proto.STRING,
        number=1,
    )


class BusinessProfileLocationGroup(proto.Message):
    r"""Information about a Business Profile dynamic location group. Only
    applicable if the sync level AssetSet's type is LOCATION_SYNC and
    sync source is Business Profile.

    Attributes:
        dynamic_business_profile_location_group_filter (google.ads.googleads.v22.common.types.DynamicBusinessProfileLocationGroupFilter):
            Filter for dynamic Business Profile location
            sets.
    """

    dynamic_business_profile_location_group_filter: (
        "DynamicBusinessProfileLocationGroupFilter"
    ) = proto.Field(
        proto.MESSAGE,
        number=1,
        message="DynamicBusinessProfileLocationGroupFilter",
    )


class DynamicBusinessProfileLocationGroupFilter(proto.Message):
    r"""Represents a filter on Business Profile locations in an asset
    set. If multiple filters are provided, they are AND'ed together.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        label_filters (MutableSequence[str]):
            Used to filter Business Profile locations by
            label. Only locations that have any of the
            listed labels will be in the asset set. Label
            filters are OR'ed together.
        business_name_filter (google.ads.googleads.v22.common.types.BusinessProfileBusinessNameFilter):
            Used to filter Business Profile locations by
            business name.

            This field is a member of `oneof`_ ``_business_name_filter``.
        listing_id_filters (MutableSequence[int]):
            Used to filter Business Profile locations by
            listing ids.
    """

    label_filters: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    business_name_filter: "BusinessProfileBusinessNameFilter" = proto.Field(
        proto.MESSAGE,
        number=2,
        optional=True,
        message="BusinessProfileBusinessNameFilter",
    )
    listing_id_filters: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=3,
    )


class BusinessProfileBusinessNameFilter(proto.Message):
    r"""Business Profile location group business name filter.

    Attributes:
        business_name (str):
            Business name string to use for filtering.
        filter_type (google.ads.googleads.v22.enums.types.LocationStringFilterTypeEnum.LocationStringFilterType):
            The type of string matching to use when filtering with
            business_name.
    """

    business_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter_type: (
        location_string_filter_type.LocationStringFilterTypeEnum.LocationStringFilterType
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=location_string_filter_type.LocationStringFilterTypeEnum.LocationStringFilterType,
    )


class ChainLocationGroup(proto.Message):
    r"""Represents information about a Chain dynamic location group. Only
    applicable if the sync level AssetSet's type is LOCATION_SYNC and
    sync source is chain.

    Attributes:
        dynamic_chain_location_group_filters (MutableSequence[google.ads.googleads.v22.common.types.ChainFilter]):
            Used to filter chain locations by chain ids.
            Only Locations that belong to the specified
            chain(s) will be in the asset set.
    """

    dynamic_chain_location_group_filters: MutableSequence["ChainFilter"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message="ChainFilter",
        )
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v19.resources.types import customer_client_link
from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.services",
    marshal="google.ads.googleads.v19",
    manifest={
        "MutateCustomerClientLinkRequest",
        "CustomerClientLinkOperation",
        "MutateCustomerClientLinkResponse",
        "MutateCustomerClientLinkResult",
    },
)


class MutateCustomerClientLinkRequest(proto.Message):
    r"""Request message for
    [CustomerClientLinkService.MutateCustomerClientLink][google.ads.googleads.v19.services.CustomerClientLinkService.MutateCustomerClientLink].

    Attributes:
        customer_id (str):
            Required. The ID of the customer whose
            customer link are being modified.
        operation (google.ads.googleads.v19.services.types.CustomerClientLinkOperation):
            Required. The operation to perform on the
            individual CustomerClientLink.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    operation: "CustomerClientLinkOperation" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="CustomerClientLinkOperation",
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class CustomerClientLinkOperation(proto.Message):
    r"""A single operation (create, update) on a CustomerClientLink.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            FieldMask that determines which resource
            fields are modified in an update.
        create (google.ads.googleads.v19.resources.types.CustomerClientLink):
            Create operation: No resource name is
            expected for the new link.

            This field is a member of `oneof`_ ``operation``.
        update (google.ads.googleads.v19.resources.types.CustomerClientLink):
            Update operation: The link is expected to
            have a valid resource name.

            This field is a member of `oneof`_ ``operation``.
    """

    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=4,
        message=field_mask_pb2.FieldMask,
    )
    create: customer_client_link.CustomerClientLink = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="operation",
        message=customer_client_link.CustomerClientLink,
    )
    update: customer_client_link.CustomerClientLink = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="operation",
        message=customer_client_link.CustomerClientLink,
    )


class MutateCustomerClientLinkResponse(proto.Message):
    r"""Response message for a CustomerClientLink mutate.

    Attributes:
        result (google.ads.googleads.v19.services.types.MutateCustomerClientLinkResult):
            A result that identifies the resource
            affected by the mutate request.
    """

    result: "MutateCustomerClientLinkResult" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="MutateCustomerClientLinkResult",
    )


class MutateCustomerClientLinkResult(proto.Message):
    r"""The result for a single customer client link mutate.

    Attributes:
        resource_name (str):
            Returned for successful operations.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict

from .base import KeywordPlanCampaignKeywordServiceTransport
from .grpc import KeywordPlanCampaignKeywordServiceGrpcTransport
from .grpc_asyncio import KeywordPlanCampaignKeywordServiceGrpcAsyncIOTransport


# Compile a registry of transports.
_transport_registry = (
    OrderedDict()
)  # type: Dict[str, Type[KeywordPlanCampaignKeywordServiceTransport]]
_transport_registry["grpc"] = KeywordPlanCampaignKeywordServiceGrpcTransport
_transport_registry["grpc_asyncio"] = (
    KeywordPlanCampaignKeywordServiceGrpcAsyncIOTransport
)

__all__ = (
    "KeywordPlanCampaignKeywordServiceTransport",
    "KeywordPlanCampaignKeywordServiceGrpcTransport",
    "KeywordPlanCampaignKeywordServiceGrpcAsyncIOTransport",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v22.enums.types import (
    product_link_invitation_status as gage_product_link_invitation_status,
)
from google.ads.googleads.v22.resources.types import (
    product_link_invitation as gagr_product_link_invitation,
)


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.services",
    marshal="google.ads.googleads.v22",
    manifest={
        "CreateProductLinkInvitationRequest",
        "CreateProductLinkInvitationResponse",
        "UpdateProductLinkInvitationRequest",
        "UpdateProductLinkInvitationResponse",
        "RemoveProductLinkInvitationRequest",
        "RemoveProductLinkInvitationResponse",
    },
)


class CreateProductLinkInvitationRequest(proto.Message):
    r"""Request message for
    [ProductLinkInvitationService.CreateProductLinkInvitation][google.ads.googleads.v22.services.ProductLinkInvitationService.CreateProductLinkInvitation].

    Attributes:
        customer_id (str):
            Required. The ID of the customer being
            modified.
        product_link_invitation (google.ads.googleads.v22.resources.types.ProductLinkInvitation):
            Required. The product link invitation to be
            created.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    product_link_invitation: (
        gagr_product_link_invitation.ProductLinkInvitation
    ) = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gagr_product_link_invitation.ProductLinkInvitation,
    )


class CreateProductLinkInvitationResponse(proto.Message):
    r"""Response message for product link invitation create.

    Attributes:
        resource_name (str):
            Resource name of the product link invitation.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateProductLinkInvitationRequest(proto.Message):
    r"""Request message for
    [ProductLinkInvitationService.UpdateProductLinkInvitation][google.ads.googleads.v22.services.ProductLinkInvitationService.UpdateProductLinkInvitation].

    Attributes:
        customer_id (str):
            Required. The ID of the customer being
            modified.
        product_link_invitation_status (google.ads.googleads.v22.enums.types.ProductLinkInvitationStatusEnum.ProductLinkInvitationStatus):
            Required. The product link invitation to be
            created.
        resource_name (str):
            Required. Resource name of the product link
            invitation.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    product_link_invitation_status: (
        gage_product_link_invitation_status.ProductLinkInvitationStatusEnum.ProductLinkInvitationStatus
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=gage_product_link_invitation_status.ProductLinkInvitationStatusEnum.ProductLinkInvitationStatus,
    )
    resource_name: str = proto.Field(
        proto.STRING,
        number=3,
    )


class UpdateProductLinkInvitationResponse(proto.Message):
    r"""Response message for product link invitation update.

    Attributes:
        resource_name (str):
            Result of the update.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class RemoveProductLinkInvitationRequest(proto.Message):
    r"""Request message for
    [ProductLinkinvitationService.RemoveProductLinkInvitation][].

    Attributes:
        customer_id (str):
            Required. The ID of the product link
            invitation being removed.
        resource_name (str):
            Required. The resource name of the product link invitation
            being removed. expected, in this format:

            ````
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    resource_name: str = proto.Field(
        proto.STRING,
        number=2,
    )


class RemoveProductLinkInvitationResponse(proto.Message):
    r"""Response message for product link invitation removeal.

    Attributes:
        resource_name (str):
            Result for the remove request.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.errors",
    marshal="google.ads.googleads.v20",
    manifest={
        "DateErrorEnum",
    },
)


class DateErrorEnum(proto.Message):
    r"""Container for enum describing possible date errors."""

    class DateError(proto.Enum):
        r"""Enum describing possible date errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            INVALID_FIELD_VALUES_IN_DATE (2):
                Given field values do not correspond to a
                valid date.
            INVALID_FIELD_VALUES_IN_DATE_TIME (3):
                Given field values do not correspond to a
                valid date time.
            INVALID_STRING_DATE (4):
                The string date's format should be
                yyyy-mm-dd.
            INVALID_STRING_DATE_TIME_MICROS (6):
                The string date time's format should be
                yyyy-mm-dd hh:mm:ss.ssssss.
            INVALID_STRING_DATE_TIME_SECONDS (11):
                The string date time's format should be
                yyyy-mm-dd hh:mm:ss.
            INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET (12):
                The string date time's format should be yyyy-mm-dd
                hh:mm:ss+|-hh:mm.
            EARLIER_THAN_MINIMUM_DATE (7):
                Date is before allowed minimum.
            LATER_THAN_MAXIMUM_DATE (8):
                Date is after allowed maximum.
            DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE (9):
                Date range bounds are not in order.
            DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL (10):
                Both dates in range are null.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        INVALID_FIELD_VALUES_IN_DATE = 2
        INVALID_FIELD_VALUES_IN_DATE_TIME = 3
        INVALID_STRING_DATE = 4
        INVALID_STRING_DATE_TIME_MICROS = 6
        INVALID_STRING_DATE_TIME_SECONDS = 11
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = 12
        EARLIER_THAN_MINIMUM_DATE = 7
        LATER_THAN_MAXIMUM_DATE = 8
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = 9
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = 10


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v22.resources.types import asset_group_asset
from google.protobuf import field_mask_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.services",
    marshal="google.ads.googleads.v22",
    manifest={
        "MutateAssetGroupAssetsRequest",
        "AssetGroupAssetOperation",
        "MutateAssetGroupAssetsResponse",
        "MutateAssetGroupAssetResult",
    },
)


class MutateAssetGroupAssetsRequest(proto.Message):
    r"""Request message for
    [AssetGroupAssetService.MutateAssetGroupAssets][google.ads.googleads.v22.services.AssetGroupAssetService.MutateAssetGroupAssets].

    Attributes:
        customer_id (str):
            Required. The ID of the customer whose asset
            group assets are being modified.
        operations (MutableSequence[google.ads.googleads.v22.services.types.AssetGroupAssetOperation]):
            Required. The list of operations to perform
            on individual asset group assets.
        partial_failure (bool):
            If true, successful operations will be
            carried out and invalid operations will return
            errors. If false, all operations will be carried
            out in one transaction if and only if they are
            all valid. Default is false.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    operations: MutableSequence["AssetGroupAssetOperation"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="AssetGroupAssetOperation",
        )
    )
    partial_failure: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class AssetGroupAssetOperation(proto.Message):
    r"""A single operation (create, remove) on an asset group asset.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            FieldMask that determines which resource
            fields are modified in an update.
        create (google.ads.googleads.v22.resources.types.AssetGroupAsset):
            Create operation: No resource name is
            expected for the new asset group asset.

            This field is a member of `oneof`_ ``operation``.
        update (google.ads.googleads.v22.resources.types.AssetGroupAsset):
            Update operation: The asset group asset is
            expected to have a valid resource name.

            This field is a member of `oneof`_ ``operation``.
        remove (str):
            Remove operation: A resource name for the removed asset
            group asset is expected, in this format:
            ``customers/{customer_id}/assetGroupAssets/{asset_group_id}~{asset_id}~{field_type}``

            This field is a member of `oneof`_ ``operation``.
    """

    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=4,
        message=field_mask_pb2.FieldMask,
    )
    create: asset_group_asset.AssetGroupAsset = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="operation",
        message=asset_group_asset.AssetGroupAsset,
    )
    update: asset_group_asset.AssetGroupAsset = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="operation",
        message=asset_group_asset.AssetGroupAsset,
    )
    remove: str = proto.Field(
        proto.STRING,
        number=3,
        oneof="operation",
    )


class MutateAssetGroupAssetsResponse(proto.Message):
    r"""Response message for an asset group asset mutate.

    Attributes:
        results (MutableSequence[google.ads.googleads.v22.services.types.MutateAssetGroupAssetResult]):
            All results for the mutate.
        partial_failure_error (google.rpc.status_pb2.Status):
            Errors that pertain to operation failures in the partial
            failure mode. Returned only when partial_failure = true and
            all errors occur inside the operations. If any errors occur
            outside the operations (for example, auth errors), we return
            an RPC level error.
    """

    results: MutableSequence["MutateAssetGroupAssetResult"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message="MutateAssetGroupAssetResult",
        )
    )
    partial_failure_error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=2,
        message=status_pb2.Status,
    )


class MutateAssetGroupAssetResult(proto.Message):
    r"""The result for the asset group asset mutate.

    Attributes:
        resource_name (str):
            Returned for successful operations.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.enums",
    marshal="google.ads.googleads.v21",
    manifest={
        "LeadFormFieldUserInputTypeEnum",
    },
)


class LeadFormFieldUserInputTypeEnum(proto.Message):
    r"""Describes the input type of a lead form field."""

    class LeadFormFieldUserInputType(proto.Enum):
        r"""Enum describing the input type of a lead form field.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            FULL_NAME (2):
                The user will be asked to fill in their given and family
                name. This field cannot be set at the same time as
                GIVEN_NAME or FAMILY_NAME.
            EMAIL (3):
                The user will be asked to fill in their email
                address.
            PHONE_NUMBER (4):
                The user will be asked to fill in their phone
                number.
            POSTAL_CODE (5):
                The user will be asked to fill in their zip
                code.
            STREET_ADDRESS (8):
                The user will be asked to fill in their
                street address.
            CITY (9):
                The user will be asked to fill in their city.
            REGION (10):
                The user will be asked to fill in their
                region part of the address (for example, state
                for US, province for Canada).
            COUNTRY (11):
                The user will be asked to fill in their
                country.
            WORK_EMAIL (12):
                The user will be asked to fill in their work
                email address.
            COMPANY_NAME (13):
                The user will be asked to fill in their
                company name.
            WORK_PHONE (14):
                The user will be asked to fill in their work
                phone.
            JOB_TITLE (15):
                The user will be asked to fill in their job
                title.
            GOVERNMENT_ISSUED_ID_CPF_BR (16):
                The user will be asked to fill in their CPF
                for Brazil users.
            GOVERNMENT_ISSUED_ID_DNI_AR (17):
                The user will be asked to fill in their DNI
                for Argentina users.
            GOVERNMENT_ISSUED_ID_DNI_PE (18):
                The user will be asked to fill in their DNI
                for Peru users.
            GOVERNMENT_ISSUED_ID_RUT_CL (19):
                The user will be asked to fill in their RUT
                for Chile users.
            GOVERNMENT_ISSUED_ID_CC_CO (20):
                The user will be asked to fill in their CC
                for Colombia users.
            GOVERNMENT_ISSUED_ID_CI_EC (21):
                The user will be asked to fill in their CI
                for Ecuador users.
            GOVERNMENT_ISSUED_ID_RFC_MX (22):
                The user will be asked to fill in their RFC
                for Mexico users.
            FIRST_NAME (23):
                The user will be asked to fill in their first name. This
                field can not be set at the same time as FULL_NAME.
            LAST_NAME (24):
                The user will be asked to fill in their last name. This
                field can not be set at the same time as FULL_NAME.
            VEHICLE_MODEL (1001):
                Question: "Which model are you interested in?" Category:
                "Auto" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            VEHICLE_TYPE (1002):
                Question: "Which type of vehicle are you interested in?"
                Category: "Auto" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PREFERRED_DEALERSHIP (1003):
                Question: "What is your preferred dealership?" Category:
                "Auto" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            VEHICLE_PURCHASE_TIMELINE (1004):
                Question: "When do you plan on purchasing a vehicle?"
                Category: "Auto" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            VEHICLE_OWNERSHIP (1005):
                Question: "Do you own a vehicle?" Category: "Auto" This
                field is subject to a limit of 5 qualifying questions per
                form and cannot be used if values are set using
                custom_question_fields.
            VEHICLE_PAYMENT_TYPE (1009):
                Question: "What vehicle ownership option are you interested
                in?" Category: "Auto" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            VEHICLE_CONDITION (1010):
                Question: "What type of vehicle condition are you interested
                in?" Category: "Auto" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            COMPANY_SIZE (1006):
                Question: "What size is your company?" Category: "Business"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            ANNUAL_SALES (1007):
                Question: "What is your annual sales volume?" Category:
                "Business" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            YEARS_IN_BUSINESS (1008):
                Question: "How many years have you been in business?"
                Category: "Business" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            JOB_DEPARTMENT (1011):
                Question: "What is your job department?" Category:
                "Business" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            JOB_ROLE (1012):
                Question: "What is your job role?" Category: "Business" This
                field is subject to a limit of 5 qualifying questions per
                form and cannot be used if values are set using
                custom_question_fields.
            OVER_18_AGE (1078):
                Question: "Are you over 18 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_19_AGE (1079):
                Question: "Are you over 19 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_20_AGE (1080):
                Question: "Are you over 20 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_21_AGE (1081):
                Question: "Are you over 21 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_22_AGE (1082):
                Question: "Are you over 22 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_23_AGE (1083):
                Question: "Are you over 23 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_24_AGE (1084):
                Question: "Are you over 24 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_25_AGE (1085):
                Question: "Are you over 25 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_26_AGE (1086):
                Question: "Are you over 26 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_27_AGE (1087):
                Question: "Are you over 27 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_28_AGE (1088):
                Question: "Are you over 28 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_29_AGE (1089):
                Question: "Are you over 29 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_30_AGE (1090):
                Question: "Are you over 30 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_31_AGE (1091):
                Question: "Are you over 31 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_32_AGE (1092):
                Question: "Are you over 32 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_33_AGE (1093):
                Question: "Are you over 33 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_34_AGE (1094):
                Question: "Are you over 34 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_35_AGE (1095):
                Question: "Are you over 35 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_36_AGE (1096):
                Question: "Are you over 36 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_37_AGE (1097):
                Question: "Are you over 37 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_38_AGE (1098):
                Question: "Are you over 38 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_39_AGE (1099):
                Question: "Are you over 39 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_40_AGE (1100):
                Question: "Are you over 40 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_41_AGE (1101):
                Question: "Are you over 41 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_42_AGE (1102):
                Question: "Are you over 42 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_43_AGE (1103):
                Question: "Are you over 43 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_44_AGE (1104):
                Question: "Are you over 44 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_45_AGE (1105):
                Question: "Are you over 45 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_46_AGE (1106):
                Question: "Are you over 46 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_47_AGE (1107):
                Question: "Are you over 47 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_48_AGE (1108):
                Question: "Are you over 48 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_49_AGE (1109):
                Question: "Are you over 49 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_50_AGE (1110):
                Question: "Are you over 50 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_51_AGE (1111):
                Question: "Are you over 51 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_52_AGE (1112):
                Question: "Are you over 52 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_53_AGE (1113):
                Question: "Are you over 53 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_54_AGE (1114):
                Question: "Are you over 54 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_55_AGE (1115):
                Question: "Are you over 55 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_56_AGE (1116):
                Question: "Are you over 56 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_57_AGE (1117):
                Question: "Are you over 57 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_58_AGE (1118):
                Question: "Are you over 58 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_59_AGE (1119):
                Question: "Are you over 59 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_60_AGE (1120):
                Question: "Are you over 60 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_61_AGE (1121):
                Question: "Are you over 61 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_62_AGE (1122):
                Question: "Are you over 62 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_63_AGE (1123):
                Question: "Are you over 63 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_64_AGE (1124):
                Question: "Are you over 64 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            OVER_65_AGE (1125):
                Question: "Are you over 65 years of age?" Category:
                "Demographics" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            EDUCATION_PROGRAM (1013):
                Question: "Which program are you interested in?" Category:
                "Education" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            EDUCATION_COURSE (1014):
                Question: "Which course are you interested in?" Category:
                "Education" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            PRODUCT (1016):
                Question: "Which product are you interested in?" Category:
                "General" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            SERVICE (1017):
                Question: "Which service are you interested in?" Category:
                "General" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            OFFER (1018):
                Question: "Which offer are you interested in?" Category:
                "General" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            CATEGORY (1019):
                Question: "Which category are you interested in?" Category:
                "General" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            PREFERRED_CONTACT_METHOD (1020):
                Question: "What is your preferred method of contact?"
                Category: "General" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PREFERRED_LOCATION (1021):
                Question: "What is your preferred location?" Category:
                "General" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            PREFERRED_CONTACT_TIME (1022):
                Question: "What is the best time to contact you?" Category:
                "General" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            PURCHASE_TIMELINE (1023):
                Question: "When are you looking to make a purchase?"
                Category: "General" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            YEARS_OF_EXPERIENCE (1048):
                Question: "How many years of work experience do you have?"
                Category: "Jobs" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            JOB_INDUSTRY (1049):
                Question: "What industry do you work in?" Category: "Jobs"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            LEVEL_OF_EDUCATION (1050):
                Question: "What is your highest level of education?"
                Category: "Jobs" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PROPERTY_TYPE (1024):
                Question: "What type of property are you looking for?"
                Category: "Real Estate" This field is subject to a limit of
                5 qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            REALTOR_HELP_GOAL (1025):
                Question: "What do you need a realtor's help with?"
                Category: "Real Estate" This field is subject to a limit of
                5 qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PROPERTY_COMMUNITY (1026):
                Question: "What neighborhood are you interested in?"
                Category: "Real Estate" This field is subject to a limit of
                5 qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PRICE_RANGE (1027):
                Question: "What price range are you looking for?" Category:
                "Real Estate" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            NUMBER_OF_BEDROOMS (1028):
                Question: "How many bedrooms are you looking for?" Category:
                "Real Estate" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            FURNISHED_PROPERTY (1029):
                Question: "Are you looking for a fully furnished property?"
                Category: "Real Estate" This field is subject to a limit of
                5 qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PETS_ALLOWED_PROPERTY (1030):
                Question: "Are you looking for properties that allow pets?"
                Category: "Real Estate" This field is subject to a limit of
                5 qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            NEXT_PLANNED_PURCHASE (1031):
                Question: "What is the next product you plan to purchase?"
                Category: "Retail" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            EVENT_SIGNUP_INTEREST (1033):
                Question: "Would you like to sign up for an event?"
                Category: "Retail" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            PREFERRED_SHOPPING_PLACES (1034):
                Question: "Where are you interested in shopping?" Category:
                "Retail" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            FAVORITE_BRAND (1035):
                Question: "What is your favorite brand?" Category: "Retail"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            TRANSPORTATION_COMMERCIAL_LICENSE_TYPE (1036):
                Question: "Which type of valid commercial license do you
                have?" Category: "Transportation" This field is subject to a
                limit of 5 qualifying questions per form and cannot be used
                if values are set using custom_question_fields.
            EVENT_BOOKING_INTEREST (1038):
                Question: "Interested in booking an event?" Category:
                "Travel" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            DESTINATION_COUNTRY (1039):
                Question: "What is your destination country?" Category:
                "Travel" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            DESTINATION_CITY (1040):
                Question: "What is your destination city?" Category:
                "Travel" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            DEPARTURE_COUNTRY (1041):
                Question: "What is your departure country?" Category:
                "Travel" This field is subject to a limit of 5 qualifying
                questions per form and cannot be used if values are set
                using custom_question_fields.
            DEPARTURE_CITY (1042):
                Question: "What is your departure city?" Category: "Travel"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            DEPARTURE_DATE (1043):
                Question: "What is your departure date?" Category: "Travel"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            RETURN_DATE (1044):
                Question: "What is your return date?" Category: "Travel"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            NUMBER_OF_TRAVELERS (1045):
                Question: "How many people are you traveling with?"
                Category: "Travel" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
            TRAVEL_BUDGET (1046):
                Question: "What is your travel budget?" Category: "Travel"
                This field is subject to a limit of 5 qualifying questions
                per form and cannot be used if values are set using
                custom_question_fields.
            TRAVEL_ACCOMMODATION (1047):
                Question: "Where do you want to stay during your travel?"
                Category: "Travel" This field is subject to a limit of 5
                qualifying questions per form and cannot be used if values
                are set using custom_question_fields.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        FULL_NAME = 2
        EMAIL = 3
        PHONE_NUMBER = 4
        POSTAL_CODE = 5
        STREET_ADDRESS = 8
        CITY = 9
        REGION = 10
        COUNTRY = 11
        WORK_EMAIL = 12
        COMPANY_NAME = 13
        WORK_PHONE = 14
        JOB_TITLE = 15
        GOVERNMENT_ISSUED_ID_CPF_BR = 16
        GOVERNMENT_ISSUED_ID_DNI_AR = 17
        GOVERNMENT_ISSUED_ID_DNI_PE = 18
        GOVERNMENT_ISSUED_ID_RUT_CL = 19
        GOVERNMENT_ISSUED_ID_CC_CO = 20
        GOVERNMENT_ISSUED_ID_CI_EC = 21
        GOVERNMENT_ISSUED_ID_RFC_MX = 22
        FIRST_NAME = 23
        LAST_NAME = 24
        VEHICLE_MODEL = 1001
        VEHICLE_TYPE = 1002
        PREFERRED_DEALERSHIP = 1003
        VEHICLE_PURCHASE_TIMELINE = 1004
        VEHICLE_OWNERSHIP = 1005
        VEHICLE_PAYMENT_TYPE = 1009
        VEHICLE_CONDITION = 1010
        COMPANY_SIZE = 1006
        ANNUAL_SALES = 1007
        YEARS_IN_BUSINESS = 1008
        JOB_DEPARTMENT = 1011
        JOB_ROLE = 1012
        OVER_18_AGE = 1078
        OVER_19_AGE = 1079
        OVER_20_AGE = 1080
        OVER_21_AGE = 1081
        OVER_22_AGE = 1082
        OVER_23_AGE = 1083
        OVER_24_AGE = 1084
        OVER_25_AGE = 1085
        OVER_26_AGE = 1086
        OVER_27_AGE = 1087
        OVER_28_AGE = 1088
        OVER_29_AGE = 1089
        OVER_30_AGE = 1090
        OVER_31_AGE = 1091
        OVER_32_AGE = 1092
        OVER_33_AGE = 1093
        OVER_34_AGE = 1094
        OVER_35_AGE = 1095
        OVER_36_AGE = 1096
        OVER_37_AGE = 1097
        OVER_38_AGE = 1098
        OVER_39_AGE = 1099
        OVER_40_AGE = 1100
        OVER_41_AGE = 1101
        OVER_42_AGE = 1102
        OVER_43_AGE = 1103
        OVER_44_AGE = 1104
        OVER_45_AGE = 1105
        OVER_46_AGE = 1106
        OVER_47_AGE = 1107
        OVER_48_AGE = 1108
        OVER_49_AGE = 1109
        OVER_50_AGE = 1110
        OVER_51_AGE = 1111
        OVER_52_AGE = 1112
        OVER_53_AGE = 1113
        OVER_54_AGE = 1114
        OVER_55_AGE = 1115
        OVER_56_AGE = 1116
        OVER_57_AGE = 1117
        OVER_58_AGE = 1118
        OVER_59_AGE = 1119
        OVER_60_AGE = 1120
        OVER_61_AGE = 1121
        OVER_62_AGE = 1122
        OVER_63_AGE = 1123
        OVER_64_AGE = 1124
        OVER_65_AGE = 1125
        EDUCATION_PROGRAM = 1013
        EDUCATION_COURSE = 1014
        PRODUCT = 1016
        SERVICE = 1017
        OFFER = 1018
        CATEGORY = 1019
        PREFERRED_CONTACT_METHOD = 1020
        PREFERRED_LOCATION = 1021
        PREFERRED_CONTACT_TIME = 1022
        PURCHASE_TIMELINE = 1023
        YEARS_OF_EXPERIENCE = 1048
        JOB_INDUSTRY = 1049
        LEVEL_OF_EDUCATION = 1050
        PROPERTY_TYPE = 1024
        REALTOR_HELP_GOAL = 1025
        PROPERTY_COMMUNITY = 1026
        PRICE_RANGE = 1027
        NUMBER_OF_BEDROOMS = 1028
        FURNISHED_PROPERTY = 1029
        PETS_ALLOWED_PROPERTY = 1030
        NEXT_PLANNED_PURCHASE = 1031
        EVENT_SIGNUP_INTEREST = 1033
        PREFERRED_SHOPPING_PLACES = 1034
        FAVORITE_BRAND = 1035
        TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = 1036
        EVENT_BOOKING_INTEREST = 1038
        DESTINATION_COUNTRY = 1039
        DESTINATION_CITY = 1040
        DEPARTURE_COUNTRY = 1041
        DEPARTURE_CITY = 1042
        DEPARTURE_DATE = 1043
        RETURN_DATE = 1044
        NUMBER_OF_TRAVELERS = 1045
        TRAVEL_BUDGET = 1046
        TRAVEL_ACCOMMODATION = 1047


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.enums",
    marshal="google.ads.googleads.v20",
    manifest={
        "TargetingDimensionEnum",
    },
)


class TargetingDimensionEnum(proto.Message):
    r"""The dimensions that can be targeted."""

    class TargetingDimension(proto.Enum):
        r"""Enum describing possible targeting dimensions.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            KEYWORD (2):
                Keyword criteria, for example, 'mars cruise'.
                KEYWORD may be used as a custom bid dimension.
                Keywords are always a targeting dimension, so
                may not be set as a target "ALL" dimension with
                TargetRestriction.
            AUDIENCE (3):
                Audience criteria, which include user list,
                user interest, custom affinity,  and custom in
                market.
            TOPIC (4):
                Topic criteria for targeting categories of
                content, for example, 'category::Animals>Pets'
                Used for Display and Video targeting.
            GENDER (5):
                Criteria for targeting gender.
            AGE_RANGE (6):
                Criteria for targeting age ranges.
            PLACEMENT (7):
                Placement criteria, which include websites
                like 'www.flowers4sale.com', as well as mobile
                applications, mobile app categories, YouTube
                videos, and YouTube channels.
            PARENTAL_STATUS (8):
                Criteria for parental status targeting.
            INCOME_RANGE (9):
                Criteria for income range targeting.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        KEYWORD = 2
        AUDIENCE = 3
        TOPIC = 4
        GENDER = 5
        AGE_RANGE = 6
        PLACEMENT = 7
        PARENTAL_STATUS = 8
        INCOME_RANGE = 9


__all__ = tuple(sorted(__protobuf__.manifest))



#!/usr/bin/env python
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Creates a rule-based user list.

The list will be defined by a combination of rules for users who have visited
two different pages of a website.
"""

import argparse
import sys
from uuid import uuid4

from google.ads.googleads.client import GoogleAdsClient
from google.ads.googleads.errors import GoogleAdsException
from google.ads.googleads.v22.common.types.user_lists import (
    FlexibleRuleOperandInfo,
    FlexibleRuleUserListInfo,
    RuleBasedUserListInfo,
    UserListRuleInfo,
    UserListRuleItemGroupInfo,
    UserListRuleItemInfo,
)
from google.ads.googleads.v22.resources.types.user_list import UserList
from google.ads.googleads.v22.services.services.user_list_service import (
    UserListServiceClient,
)
from google.ads.googleads.v22.services.types.user_list_service import (
    UserListOperation,
    MutateUserListsResponse,
)


# [START add_combined_rule_user_list]
def main(client: GoogleAdsClient, customer_id: str) -> None:
    """Creates a rule-based user list.

    The list will be defined by a combination of rules for users who have
    visited two different pages of a website.

    Args:
        client: The Google Ads client.
        customer_id: The customer ID for which to add the user list.
    """
    # Create a UserListRuleInfo object containing the first rule.
    user_visited_site1_rule_info: UserListRuleInfo = (
        create_user_list_rule_info_from_url(
            client, "http://example.com/example1"
        )
    )
    # Create a UserListRuleInfo object containing the second rule.
    user_visited_site2_rule_info: UserListRuleInfo = (
        create_user_list_rule_info_from_url(
            client, "http://example.com/example2"
        )
    )
    # Create a UserListRuleInfo object containing the third rule.
    user_visited_site3_rule_info: UserListRuleInfo = (
        create_user_list_rule_info_from_url(
            client, "http://example.com/example3"
        )
    )

    # Create the user list "Visitors of page 1 AND page 2, but not page 3".
    # To create the user list "Visitors of page 1 *OR* page 2, but not page 3",
    # change the UserListFlexibleRuleOperator from AND to OR.
    flexible_rule_user_list_info: FlexibleRuleUserListInfo = client.get_type(
        "FlexibleRuleUserListInfo"
    )
    flexible_rule_user_list_info.inclusive_rule_operator = (
        client.enums.UserListFlexibleRuleOperatorEnum.AND
    )

    # Inclusive operands are joined together with the specified
    # inclusive_rule_operator. This represents the set of users that should be
    # included in the user list.
    operand_1: FlexibleRuleOperandInfo = client.get_type(
        "FlexibleRuleOperandInfo"
    )
    operand_1.rule = user_visited_site1_rule_info
    # Optionally add a lookback window for this rule, in days.
    operand_1.lookback_window_days = 7
    flexible_rule_user_list_info.inclusive_operands.append(operand_1)

    operand_2: FlexibleRuleOperandInfo = client.get_type(
        "FlexibleRuleOperandInfo"
    )
    operand_2.rule = user_visited_site2_rule_info
    # Optionally add a lookback window for this rule, in days.
    operand_2.lookback_window_days = 7
    flexible_rule_user_list_info.inclusive_operands.append(operand_2)

    # Exclusive operands are joined together with OR.
    # This represents the set of users to be excluded from the user list.
    operand_3: FlexibleRuleOperandInfo = client.get_type(
        "FlexibleRuleOperandInfo"
    )
    operand_3.rule = user_visited_site3_rule_info
    flexible_rule_user_list_info.exclusive_operands.append(operand_3)

    # Define a representation of a user list that is generated by a rule.
    rule_based_user_list_info: RuleBasedUserListInfo = client.get_type(
        "RuleBasedUserListInfo"
    )
    # Optional: To include past users in the user list, set the
    # prepopulation_status to REQUESTED.
    rule_based_user_list_info.prepopulation_status = (
        client.enums.UserListPrepopulationStatusEnum.REQUESTED
    )
    rule_based_user_list_info.flexible_rule_user_list = (
        flexible_rule_user_list_info
    )

    # Create a user list.
    user_list_operation: UserListOperation = client.get_type(
        "UserListOperation"
    )
    user_list: UserList = user_list_operation.create
    user_list.name = (
        "All visitors to http://example.com/example1 AND "
        "http://example.com/example2 but NOT "
        f"http://example.com/example3 #{uuid4()}"
    )
    user_list.description = (
        "Visitors of both http://example.com/example1 AND "
        "http://example.com/example2 but NOT"
        "http://example.com/example3"
    )
    user_list.membership_status = client.enums.UserListMembershipStatusEnum.OPEN
    user_list.rule_based_user_list = rule_based_user_list_info

    # Issue a mutate request to add the user list, then print the results.
    user_list_service: UserListServiceClient = client.get_service(
        "UserListService"
    )
    response: MutateUserListsResponse = user_list_service.mutate_user_lists(
        customer_id=customer_id, operations=[user_list_operation]
    )
    print(
        "Created user list with resource name: "
        f"'{response.results[0].resource_name}.'"
    )
    # [END add_combined_rule_user_list]


def create_user_list_rule_info_from_url(
    client: GoogleAdsClient, url: str
) -> UserListRuleInfo:
    """Create a UserListRuleInfo targeting any user that visited the given URL.

    Args:
        client: The Google Ads client.
        url: a URL string.

    Returns:
        A UserListRuleInfo instance.
    """
    # Create a rule targeting any user that visited a URL that equals
    # the given url_string.
    user_visited_site_rule: UserListRuleItemInfo = client.get_type(
        "UserListRuleItemInfo"
    )
    # Use a built-in parameter to create a domain URL rule.
    user_visited_site_rule.name = "url__"
    user_visited_site_rule.string_rule_item.operator = (
        client.enums.UserListStringRuleItemOperatorEnum.EQUALS
    )
    user_visited_site_rule.string_rule_item.value = url

    group_info: UserListRuleItemGroupInfo = client.get_type(
        "UserListRuleItemGroupInfo"
    )
    group_info.rule_items.append(user_visited_site_rule)

    # Return a UserListRuleInfo object containing the rule.
    info: UserListRuleInfo = client.get_type("UserListRuleInfo")
    info.rule_item_groups.append(group_info)

    return info


if __name__ == "__main__":
    parser: argparse.ArgumentParser = argparse.ArgumentParser(
        description="Creates a combination user list containing users that are "
        "present on any one of the provided user lists."
    )
    # The following argument(s) should be provided to run the example.
    parser.add_argument(
        "-c",
        "--customer_id",
        type=str,
        required=True,
        help="The Google Ads customer ID.",
    )
    args: argparse.Namespace = parser.parse_args()

    # GoogleAdsClient will read the google-ads.yaml configuration file in the
    # home directory if none is specified.
    googleads_client: GoogleAdsClient = GoogleAdsClient.load_from_storage(
        version="v22"
    )

    try:
        main(googleads_client, args.customer_id)
    except GoogleAdsException as ex:
        print(
            f'Request with ID "{ex.request_id}" failed with status '
            f'"{ex.error.code().name}" and includes the following errors:'
        )
        for error in ex.failure.errors:
            print(f'\tError with message "{error.message}".')
            if error.location:
                for field_path_element in error.location.field_path_elements:
                    print(f"\t\tOn field: {field_path_element.field_name}")
        sys.exit(1)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.enums",
    marshal="google.ads.googleads.v22",
    manifest={
        "BusinessMessageCallToActionTypeEnum",
    },
)


class BusinessMessageCallToActionTypeEnum(proto.Message):
    r"""Describes the type of call-to-action phrases in a business
    message.

    """

    class BusinessMessageCallToActionType(proto.Enum):
        r"""Enum describing the type of call-to-action phrases in a
        business message.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            APPLY_NOW (2):
                Apply now.
            BOOK_NOW (3):
                Book now.
            CONTACT_US (4):
                Contact us.
            GET_INFO (5):
                Get info.
            GET_OFFER (6):
                Get offer.
            GET_QUOTE (7):
                Get quote.
            GET_STARTED (8):
                Get started.
            LEARN_MORE (9):
                Learn more.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        APPLY_NOW = 2
        BOOK_NOW = 3
        CONTACT_US = 4
        GET_INFO = 5
        GET_OFFER = 6
        GET_QUOTE = 7
        GET_STARTED = 8
        LEARN_MORE = 9


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.resources",
    marshal="google.ads.googleads.v20",
    manifest={
        "ThirdPartyAppAnalyticsLink",
    },
)


class ThirdPartyAppAnalyticsLink(proto.Message):
    r"""A data sharing connection, allowing the import of third party
    app analytics into a Google Ads Customer.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Immutable. The resource name of the third party app
            analytics link. Third party app analytics link resource
            names have the form:

            ``customers/{customer_id}/thirdPartyAppAnalyticsLinks/{account_link_id}``
        shareable_link_id (str):
            Output only. The shareable link ID that
            should be provided to the third party when
            setting up app analytics. This is able to be
            regenerated using regenerate method in the
            ThirdPartyAppAnalyticsLinkService.

            This field is a member of `oneof`_ ``_shareable_link_id``.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    shareable_link_id: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.enums",
    marshal="google.ads.googleads.v21",
    manifest={
        "PaymentModeEnum",
    },
)


class PaymentModeEnum(proto.Message):
    r"""Container for enum describing possible payment modes."""

    class PaymentMode(proto.Enum):
        r"""Enum describing possible payment modes.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            CLICKS (4):
                Pay per interaction.
            CONVERSION_VALUE (5):
                Pay per conversion value. This mode is only
                supported by campaigns with
                AdvertisingChannelType.HOTEL,
                BiddingStrategyType.COMMISSION, and
                BudgetType.STANDARD.
            CONVERSIONS (6):
                Pay per conversion. This mode is only supported by campaigns
                with AdvertisingChannelType.DISPLAY (excluding
                AdvertisingChannelSubType.DISPLAY_GMAIL),
                BiddingStrategyType.TARGET_CPA, and BudgetType.FIXED_CPA.
                The customer must also be eligible for this mode. See
                Customer.eligibility_failure_reasons for details.
            GUEST_STAY (7):
                Pay per guest stay value. This mode is only
                supported by campaigns with
                AdvertisingChannelType.HOTEL,
                BiddingStrategyType.COMMISSION, and
                BudgetType.STANDARD.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        CLICKS = 4
        CONVERSION_VALUE = 5
        CONVERSIONS = 6
        GUEST_STAY = 7


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v22.common.types import offline_user_data
from google.ads.googleads.v22.resources.types import offline_user_data_job
from google.rpc import status_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.services",
    marshal="google.ads.googleads.v22",
    manifest={
        "CreateOfflineUserDataJobRequest",
        "CreateOfflineUserDataJobResponse",
        "RunOfflineUserDataJobRequest",
        "AddOfflineUserDataJobOperationsRequest",
        "OfflineUserDataJobOperation",
        "AddOfflineUserDataJobOperationsResponse",
    },
)


class CreateOfflineUserDataJobRequest(proto.Message):
    r"""Request message for
    [OfflineUserDataJobService.CreateOfflineUserDataJob][google.ads.googleads.v22.services.OfflineUserDataJobService.CreateOfflineUserDataJob].

    Attributes:
        customer_id (str):
            Required. The ID of the customer for which to
            create an offline user data job.
        job (google.ads.googleads.v22.resources.types.OfflineUserDataJob):
            Required. The offline user data job to be
            created.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
        enable_match_rate_range_preview (bool):
            If true, match rate range for the offline
            user data job is calculated and made available
            in the resource.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job: offline_user_data_job.OfflineUserDataJob = proto.Field(
        proto.MESSAGE,
        number=2,
        message=offline_user_data_job.OfflineUserDataJob,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    enable_match_rate_range_preview: bool = proto.Field(
        proto.BOOL,
        number=5,
    )


class CreateOfflineUserDataJobResponse(proto.Message):
    r"""Response message for
    [OfflineUserDataJobService.CreateOfflineUserDataJob][google.ads.googleads.v22.services.OfflineUserDataJobService.CreateOfflineUserDataJob].

    Attributes:
        resource_name (str):
            The resource name of the OfflineUserDataJob.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class RunOfflineUserDataJobRequest(proto.Message):
    r"""Request message for
    [OfflineUserDataJobService.RunOfflineUserDataJob][google.ads.googleads.v22.services.OfflineUserDataJobService.RunOfflineUserDataJob].

    Attributes:
        resource_name (str):
            Required. The resource name of the
            OfflineUserDataJob to run.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class AddOfflineUserDataJobOperationsRequest(proto.Message):
    r"""Request message for
    [OfflineUserDataJobService.AddOfflineUserDataJobOperations][google.ads.googleads.v22.services.OfflineUserDataJobService.AddOfflineUserDataJobOperations].


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Required. The resource name of the
            OfflineUserDataJob.
        enable_partial_failure (bool):
            True to enable partial failure for the
            offline user data job.

            This field is a member of `oneof`_ ``_enable_partial_failure``.
        enable_warnings (bool):
            True to enable warnings for the offline user
            data job. When enabled, a warning will not block
            the OfflineUserDataJobOperation, and will also
            return warning messages about malformed field
            values.

            This field is a member of `oneof`_ ``_enable_warnings``.
        operations (MutableSequence[google.ads.googleads.v22.services.types.OfflineUserDataJobOperation]):
            Required. The list of operations to be done.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    enable_partial_failure: bool = proto.Field(
        proto.BOOL,
        number=4,
        optional=True,
    )
    enable_warnings: bool = proto.Field(
        proto.BOOL,
        number=6,
        optional=True,
    )
    operations: MutableSequence["OfflineUserDataJobOperation"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=3,
            message="OfflineUserDataJobOperation",
        )
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=5,
    )


class OfflineUserDataJobOperation(proto.Message):
    r"""Operation to be made for the
    AddOfflineUserDataJobOperationsRequest.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        create (google.ads.googleads.v22.common.types.UserData):
            Add the provided data to the transaction.
            Data cannot be retrieved after being uploaded.

            This field is a member of `oneof`_ ``operation``.
        remove (google.ads.googleads.v22.common.types.UserData):
            Remove the provided data from the
            transaction. Data cannot be retrieved after
            being uploaded.

            This field is a member of `oneof`_ ``operation``.
        remove_all (bool):
            Remove all previously provided data. This is
            only supported for Customer Match.

            This field is a member of `oneof`_ ``operation``.
    """

    create: offline_user_data.UserData = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="operation",
        message=offline_user_data.UserData,
    )
    remove: offline_user_data.UserData = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="operation",
        message=offline_user_data.UserData,
    )
    remove_all: bool = proto.Field(
        proto.BOOL,
        number=3,
        oneof="operation",
    )


class AddOfflineUserDataJobOperationsResponse(proto.Message):
    r"""Response message for
    [OfflineUserDataJobService.AddOfflineUserDataJobOperations][google.ads.googleads.v22.services.OfflineUserDataJobService.AddOfflineUserDataJobOperations].

    Attributes:
        partial_failure_error (google.rpc.status_pb2.Status):
            Errors that pertain to operation failures in the partial
            failure mode. Returned only when partial_failure = true and
            all errors occur inside the operations. If any errors occur
            outside the operations (for example, auth errors), we return
            an RPC level error.
        warning (google.rpc.status_pb2.Status):
            Non blocking errors that pertain to operation failures in
            the warnings mode. Returned only when enable_warnings =
            true.
    """

    partial_failure_error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=1,
        message=status_pb2.Status,
    )
    warning: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=2,
        message=status_pb2.Status,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v19.enums.types import (
    advertising_channel_sub_type as gage_advertising_channel_sub_type,
)
from google.ads.googleads.v19.enums.types import (
    advertising_channel_type as gage_advertising_channel_type,
)
from google.ads.googleads.v19.enums.types import (
    criterion_category_channel_availability_mode,
)
from google.ads.googleads.v19.enums.types import (
    criterion_category_locale_availability_mode,
)


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.common",
    marshal="google.ads.googleads.v19",
    manifest={
        "CriterionCategoryAvailability",
        "CriterionCategoryChannelAvailability",
        "CriterionCategoryLocaleAvailability",
    },
)


class CriterionCategoryAvailability(proto.Message):
    r"""Information of category availability, per advertising
    channel.

    Attributes:
        channel (google.ads.googleads.v19.common.types.CriterionCategoryChannelAvailability):
            Channel types and subtypes that are available
            to the category.
        locale (MutableSequence[google.ads.googleads.v19.common.types.CriterionCategoryLocaleAvailability]):
            Locales that are available to the category
            for the channel.
    """

    channel: "CriterionCategoryChannelAvailability" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="CriterionCategoryChannelAvailability",
    )
    locale: MutableSequence["CriterionCategoryLocaleAvailability"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="CriterionCategoryLocaleAvailability",
        )
    )


class CriterionCategoryChannelAvailability(proto.Message):
    r"""Information of advertising channel type and subtypes a
    category is available in.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        availability_mode (google.ads.googleads.v19.enums.types.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode):
            Format of the channel availability. Can be ALL_CHANNELS (the
            rest of the fields will not be set), CHANNEL_TYPE (only
            advertising_channel_type type will be set, the category is
            available to all sub types under it) or
            CHANNEL_TYPE_AND_SUBTYPES (advertising_channel_type,
            advertising_channel_sub_type, and
            include_default_channel_sub_type will all be set).
        advertising_channel_type (google.ads.googleads.v19.enums.types.AdvertisingChannelTypeEnum.AdvertisingChannelType):
            Channel type the category is available to.
        advertising_channel_sub_type (MutableSequence[google.ads.googleads.v19.enums.types.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType]):
            Channel subtypes under the channel type the
            category is available to.
        include_default_channel_sub_type (bool):
            Whether default channel sub type is included. For example,
            advertising_channel_type being DISPLAY and
            include_default_channel_sub_type being false means that the
            default display campaign where channel sub type is not set
            is not included in this availability configuration.

            This field is a member of `oneof`_ ``_include_default_channel_sub_type``.
    """

    availability_mode: (
        criterion_category_channel_availability_mode.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=criterion_category_channel_availability_mode.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode,
    )
    advertising_channel_type: (
        gage_advertising_channel_type.AdvertisingChannelTypeEnum.AdvertisingChannelType
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=gage_advertising_channel_type.AdvertisingChannelTypeEnum.AdvertisingChannelType,
    )
    advertising_channel_sub_type: MutableSequence[
        gage_advertising_channel_sub_type.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType
    ] = proto.RepeatedField(
        proto.ENUM,
        number=3,
        enum=gage_advertising_channel_sub_type.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType,
    )
    include_default_channel_sub_type: bool = proto.Field(
        proto.BOOL,
        number=5,
        optional=True,
    )


class CriterionCategoryLocaleAvailability(proto.Message):
    r"""Information about which locales a category is available in.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        availability_mode (google.ads.googleads.v19.enums.types.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode):
            Format of the locale availability. Can be LAUNCHED_TO_ALL
            (both country and language will be empty), COUNTRY (only
            country will be set), LANGUAGE (only language wil be set),
            COUNTRY_AND_LANGUAGE (both country and language will be
            set).
        country_code (str):
            The ISO-3166-1 alpha-2 country code
            associated with the category.

            This field is a member of `oneof`_ ``_country_code``.
        language_code (str):
            ISO 639-1 code of the language associated
            with the category.

            This field is a member of `oneof`_ ``_language_code``.
    """

    availability_mode: (
        criterion_category_locale_availability_mode.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=criterion_category_locale_availability_mode.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode,
    )
    country_code: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.errors",
    marshal="google.ads.googleads.v22",
    manifest={
        "FinalUrlExpansionAssetViewErrorEnum",
    },
)


class FinalUrlExpansionAssetViewErrorEnum(proto.Message):
    r"""Container for enum describing possible final url expansion
    asset view errors.

    """

    class FinalUrlExpansionAssetViewError(proto.Enum):
        r"""Enum describing possible final url expansion asset view
        errors.

        Values:
            UNSPECIFIED (0):
                Name unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            MISSING_REQUIRED_FILTER (2):
                At least one required filter has to be
                applied in the query.
            REQUIRES_ADVERTISING_CHANNEL_TYPE_FILTER (3):
                Advertising channel type filter is required.
            INVALID_ADVERTISING_CHANNEL_TYPE_IN_FILTER (4):
                Advertising channel type filter has an
                invalid value.
            CANNOT_SELECT_ASSET_GROUP (5):
                Asset group cannot be selected in the query.
            CANNOT_SELECT_AD_GROUP (6):
                Ad group cannot be selected in the query.
            REQUIRES_FILTER_BY_SINGLE_RESOURCE (7):
                A selected field/resource requires filtering
                by a single resource.
            CANNOT_SELECT_BOTH_AD_GROUP_AND_ASSET_GROUP (8):
                Both ad group and asset group cannot be
                selected in the query.
            CANNOT_FILTER_BY_BOTH_AD_GROUP_AND_ASSET_GROUP (9):
                Both ad group and asset group cannot be
                filtered in the query.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        MISSING_REQUIRED_FILTER = 2
        REQUIRES_ADVERTISING_CHANNEL_TYPE_FILTER = 3
        INVALID_ADVERTISING_CHANNEL_TYPE_IN_FILTER = 4
        CANNOT_SELECT_ASSET_GROUP = 5
        CANNOT_SELECT_AD_GROUP = 6
        REQUIRES_FILTER_BY_SINGLE_RESOURCE = 7
        CANNOT_SELECT_BOTH_AD_GROUP_AND_ASSET_GROUP = 8
        CANNOT_FILTER_BY_BOTH_AD_GROUP_AND_ASSET_GROUP = 9


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v22.resources.types import customer_label
from google.rpc import status_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.services",
    marshal="google.ads.googleads.v22",
    manifest={
        "MutateCustomerLabelsRequest",
        "CustomerLabelOperation",
        "MutateCustomerLabelsResponse",
        "MutateCustomerLabelResult",
    },
)


class MutateCustomerLabelsRequest(proto.Message):
    r"""Request message for
    [CustomerLabelService.MutateCustomerLabels][google.ads.googleads.v22.services.CustomerLabelService.MutateCustomerLabels].

    Attributes:
        customer_id (str):
            Required. ID of the customer whose
            customer-label relationships are being modified.
        operations (MutableSequence[google.ads.googleads.v22.services.types.CustomerLabelOperation]):
            Required. The list of operations to perform
            on customer-label relationships.
        partial_failure (bool):
            If true, successful operations will be
            carried out and invalid operations will return
            errors. If false, all operations will be carried
            out in one transaction if and only if they are
            all valid. Default is false.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    operations: MutableSequence["CustomerLabelOperation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="CustomerLabelOperation",
    )
    partial_failure: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class CustomerLabelOperation(proto.Message):
    r"""A single operation (create, remove) on a customer-label
    relationship.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        create (google.ads.googleads.v22.resources.types.CustomerLabel):
            Create operation: No resource name is
            expected for the new customer-label
            relationship.

            This field is a member of `oneof`_ ``operation``.
        remove (str):
            Remove operation: A resource name for the customer-label
            relationship being removed, in this format:

            ``customers/{customer_id}/customerLabels/{label_id}``

            This field is a member of `oneof`_ ``operation``.
    """

    create: customer_label.CustomerLabel = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="operation",
        message=customer_label.CustomerLabel,
    )
    remove: str = proto.Field(
        proto.STRING,
        number=2,
        oneof="operation",
    )


class MutateCustomerLabelsResponse(proto.Message):
    r"""Response message for a customer labels mutate.

    Attributes:
        partial_failure_error (google.rpc.status_pb2.Status):
            Errors that pertain to operation failures in the partial
            failure mode. Returned only when partial_failure = true and
            all errors occur inside the operations. If any errors occur
            outside the operations (for example, auth errors), we return
            an RPC level error.
        results (MutableSequence[google.ads.googleads.v22.services.types.MutateCustomerLabelResult]):
            All results for the mutate.
    """

    partial_failure_error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=3,
        message=status_pb2.Status,
    )
    results: MutableSequence["MutateCustomerLabelResult"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="MutateCustomerLabelResult",
    )


class MutateCustomerLabelResult(proto.Message):
    r"""The result for a customer label mutate.

    Attributes:
        resource_name (str):
            Returned for successful operations.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.enums",
    marshal="google.ads.googleads.v22",
    manifest={
        "CampaignPrimaryStatusReasonEnum",
    },
)


class CampaignPrimaryStatusReasonEnum(proto.Message):
    r"""Container for enum describing possible campaign primary
    status reasons.

    """

    class CampaignPrimaryStatusReason(proto.Enum):
        r"""Enum describing the possible campaign primary status reasons.
        Provides insight into why a campaign is not serving or not
        serving optimally. These reasons are aggregated to determine an
        overall campaign primary status.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            CAMPAIGN_REMOVED (2):
                The user-specified campaign status is
                removed.
            CAMPAIGN_PAUSED (3):
                The user-specified campaign status is paused.
            CAMPAIGN_PENDING (4):
                The user-specified time for this campaign to
                start is in the future.
            CAMPAIGN_ENDED (5):
                The user-specified time for this campaign to
                end has passed.
            CAMPAIGN_DRAFT (6):
                The campaign is a draft.
            BIDDING_STRATEGY_MISCONFIGURED (7):
                The bidding strategy has incorrect
                user-specified settings.
            BIDDING_STRATEGY_LIMITED (8):
                The bidding strategy is limited by
                user-specified settings such as lack of data or
                similar.
            BIDDING_STRATEGY_LEARNING (9):
                The automated bidding system is adjusting to
                user-specified changes to the bidding strategy.
            BIDDING_STRATEGY_CONSTRAINED (10):
                Campaign could capture more conversion value
                by adjusting CPA/ROAS targets.
            BUDGET_CONSTRAINED (11):
                The budget is limiting the campaign's ability
                to serve.
            BUDGET_MISCONFIGURED (12):
                The budget has incorrect user-specified
                settings.
            SEARCH_VOLUME_LIMITED (13):
                Campaign is not targeting all relevant
                queries.
            AD_GROUPS_PAUSED (14):
                The user-specified ad group statuses are all
                paused.
            NO_AD_GROUPS (15):
                No eligible ad groups exist in this campaign.
            KEYWORDS_PAUSED (16):
                The user-specified keyword statuses are all
                paused.
            NO_KEYWORDS (17):
                No eligible keywords exist in this campaign.
            AD_GROUP_ADS_PAUSED (18):
                The user-specified ad group ad statuses are
                all paused.
            NO_AD_GROUP_ADS (19):
                No eligible ad group ads exist in this
                campaign.
            HAS_ADS_LIMITED_BY_POLICY (20):
                At least one ad in this campaign is limited
                by policy.
            HAS_ADS_DISAPPROVED (21):
                At least one ad in this campaign is
                disapproved.
            MOST_ADS_UNDER_REVIEW (22):
                Most ads in this campaign are pending review.
            MISSING_LEAD_FORM_EXTENSION (23):
                The campaign has a lead form goal, and the
                lead form extension is missing.
            MISSING_CALL_EXTENSION (24):
                The campaign has a call goal, and the call
                extension is missing.
            LEAD_FORM_EXTENSION_UNDER_REVIEW (25):
                The lead form extension is under review.
            LEAD_FORM_EXTENSION_DISAPPROVED (26):
                The lead extension is disapproved.
            CALL_EXTENSION_UNDER_REVIEW (27):
                The call extension is under review.
            CALL_EXTENSION_DISAPPROVED (28):
                The call extension is disapproved.
            NO_MOBILE_APPLICATION_AD_GROUP_CRITERIA (29):
                No eligible mobile application ad group
                criteria exist in this campaign.
            CAMPAIGN_GROUP_PAUSED (30):
                The user-specified campaign group status is
                paused.
            CAMPAIGN_GROUP_ALL_GROUP_BUDGETS_ENDED (31):
                The user-specified times of all group budgets
                associated with the parent campaign group has
                passed.
            APP_NOT_RELEASED (32):
                The app associated with this ACi campaign is
                not released in the target countries of the
                campaign.
            APP_PARTIALLY_RELEASED (33):
                The app associated with this ACi campaign is
                partially released in the target countries of
                the campaign.
            HAS_ASSET_GROUPS_DISAPPROVED (34):
                At least one asset group in this campaign is
                disapproved.
            HAS_ASSET_GROUPS_LIMITED_BY_POLICY (35):
                At least one asset group in this campaign is
                limited by policy.
            MOST_ASSET_GROUPS_UNDER_REVIEW (36):
                Most asset groups in this campaign are
                pending review.
            NO_ASSET_GROUPS (37):
                No eligible asset groups exist in this
                campaign.
            ASSET_GROUPS_PAUSED (38):
                All asset groups in this campaign are paused.
            MISSING_LOCATION_TARGETING (39):
                The campaign has location restrictions but
                does not specify location targeting.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        CAMPAIGN_REMOVED = 2
        CAMPAIGN_PAUSED = 3
        CAMPAIGN_PENDING = 4
        CAMPAIGN_ENDED = 5
        CAMPAIGN_DRAFT = 6
        BIDDING_STRATEGY_MISCONFIGURED = 7
        BIDDING_STRATEGY_LIMITED = 8
        BIDDING_STRATEGY_LEARNING = 9
        BIDDING_STRATEGY_CONSTRAINED = 10
        BUDGET_CONSTRAINED = 11
        BUDGET_MISCONFIGURED = 12
        SEARCH_VOLUME_LIMITED = 13
        AD_GROUPS_PAUSED = 14
        NO_AD_GROUPS = 15
        KEYWORDS_PAUSED = 16
        NO_KEYWORDS = 17
        AD_GROUP_ADS_PAUSED = 18
        NO_AD_GROUP_ADS = 19
        HAS_ADS_LIMITED_BY_POLICY = 20
        HAS_ADS_DISAPPROVED = 21
        MOST_ADS_UNDER_REVIEW = 22
        MISSING_LEAD_FORM_EXTENSION = 23
        MISSING_CALL_EXTENSION = 24
        LEAD_FORM_EXTENSION_UNDER_REVIEW = 25
        LEAD_FORM_EXTENSION_DISAPPROVED = 26
        CALL_EXTENSION_UNDER_REVIEW = 27
        CALL_EXTENSION_DISAPPROVED = 28
        NO_MOBILE_APPLICATION_AD_GROUP_CRITERIA = 29
        CAMPAIGN_GROUP_PAUSED = 30
        CAMPAIGN_GROUP_ALL_GROUP_BUDGETS_ENDED = 31
        APP_NOT_RELEASED = 32
        APP_PARTIALLY_RELEASED = 33
        HAS_ASSET_GROUPS_DISAPPROVED = 34
        HAS_ASSET_GROUPS_LIMITED_BY_POLICY = 35
        MOST_ASSET_GROUPS_UNDER_REVIEW = 36
        NO_ASSET_GROUPS = 37
        ASSET_GROUPS_PAUSED = 38
        MISSING_LOCATION_TARGETING = 39


__all__ = tuple(sorted(__protobuf__.manifest))



#!/usr/bin/env python
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Updates a campaign criterion with a new bid modifier."""

import argparse
import sys

from google.api_core import protobuf_helpers

from google.ads.googleads.client import GoogleAdsClient
from google.ads.googleads.errors import GoogleAdsException
from google.ads.googleads.v22.services.services.campaign_criterion_service import (
    CampaignCriterionServiceClient,
)
from google.ads.googleads.v22.services.types.campaign_criterion_service import (
    CampaignCriterionOperation,
    MutateCampaignCriteriaResponse,
)
from google.ads.googleads.v22.resources.types.campaign_criterion import (
    CampaignCriterion,
)


def main(
    client: GoogleAdsClient,
    customer_id: str,
    campaign_id: str,
    criterion_id: str,
    bid_modifier_value: float,
) -> None:
    campaign_criterion_service: CampaignCriterionServiceClient = (
        client.get_service("CampaignCriterionService")
    )

    criterion_rname: str = campaign_criterion_service.campaign_criterion_path(
        customer_id, campaign_id, criterion_id
    )

    campaign_criterion_operation: CampaignCriterionOperation = client.get_type(
        "CampaignCriterionOperation"
    )
    campaign_criterion: CampaignCriterion = campaign_criterion_operation.update
    campaign_criterion.resource_name = criterion_rname
    campaign_criterion.bid_modifier = bid_modifier_value
    client.copy_from(
        campaign_criterion_operation.update_mask,
        protobuf_helpers.field_mask(None, campaign_criterion._pb),
    )

    campaign_criterion_response: MutateCampaignCriteriaResponse = (
        campaign_criterion_service.mutate_campaign_criteria(
            customer_id=customer_id,
            operations=[campaign_criterion_operation],
        )
    )

    print(
        "Campaign criterion with resource name "
        f'"{campaign_criterion_response.results[0].resource_name}" was '
        "modified."
    )


if __name__ == "__main__":
    parser: argparse.ArgumentParser = argparse.ArgumentParser(
        description=(
            "Updates the bid modifier and device type for the given "
            "customer ID and campaign criterion ID."
        )
    )
    # The following argument(s) should be provided to run the example.
    parser.add_argument(
        "-c",
        "--customer_id",
        type=str,
        required=True,
        help="The Google Ads customer ID.",
    )
    parser.add_argument(
        "-i", "--campaign_id", type=str, required=True, help="The campaign ID."
    )
    parser.add_argument(
        "-k",
        "--criterion_id",
        type=str,
        required=True,
        help="The criterion ID.",
    )
    parser.add_argument(
        "-b",
        "--bid_modifier_value",
        type=float,
        default=1.5,
        help="The desired campaign criterion bid modifier.",
    )
    args: argparse.Namespace = parser.parse_args()

    # GoogleAdsClient will read the google-ads.yaml configuration file in the
    # home directory if none is specified.
    googleads_client: GoogleAdsClient = GoogleAdsClient.load_from_storage(
        version="v22"
    )

    try:
        main(
            googleads_client,
            args.customer_id,
            args.campaign_id,
            args.criterion_id,
            args.bid_modifier_value,
        )
    except GoogleAdsException as ex:
        print(
            f'Request with ID "{ex.request_id}" failed with status '
            f'"{ex.error.code().name}" and includes the following errors:'
        )
        for error in ex.failure.errors:
            print(f'\tError with message "{error.message}".')
            if error.location:
                for field_path_element in error.location.field_path_elements:
                    print(f"\t\tOn field: {field_path_element.field_name}")
        sys.exit(1)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v21.enums.types import campaign_group_status


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.resources",
    marshal="google.ads.googleads.v21",
    manifest={
        "CampaignGroup",
    },
)


class CampaignGroup(proto.Message):
    r"""A campaign group.

    Attributes:
        resource_name (str):
            Immutable. The resource name of the campaign group. Campaign
            group resource names have the form:

            ``customers/{customer_id}/campaignGroups/{campaign_group_id}``
        id (int):
            Output only. The ID of the campaign group.
        name (str):
            The name of the campaign group.

            This field is required and should not be empty
            when creating new campaign groups.

            It must not contain any null (code point 0x0),
            NL line feed (code point 0xA) or carriage return
            (code point 0xD) characters.
        status (google.ads.googleads.v21.enums.types.CampaignGroupStatusEnum.CampaignGroupStatus):
            The status of the campaign group.

            When a new campaign group is added, the status
            defaults to ENABLED.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: int = proto.Field(
        proto.INT64,
        number=3,
    )
    name: str = proto.Field(
        proto.STRING,
        number=4,
    )
    status: (
        campaign_group_status.CampaignGroupStatusEnum.CampaignGroupStatus
    ) = proto.Field(
        proto.ENUM,
        number=5,
        enum=campaign_group_status.CampaignGroupStatusEnum.CampaignGroupStatus,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .ad_asset import (
    AdAppDeepLinkAsset,
    AdCallToActionAsset,
    AdDemandGenCarouselCardAsset,
    AdImageAsset,
    AdMediaBundleAsset,
    AdTextAsset,
    AdVideoAsset,
    AdVideoAssetInfo,
    AdVideoAssetInventoryPreferences,
)
from .ad_type_infos import (
    AppAdInfo,
    AppEngagementAdInfo,
    AppPreRegistrationAdInfo,
    CallAdInfo,
    DemandGenCarouselAdInfo,
    DemandGenMultiAssetAdInfo,
    DemandGenProductAdInfo,
    DemandGenVideoResponsiveAdInfo,
    DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo,
    HotelAdInfo,
    ImageAdInfo,
    InFeedVideoAdInfo,
    LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo,
    LocalAdInfo,
    ResponsiveDisplayAdControlSpec,
    ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo,
    ShoppingSmartAdInfo,
    SmartCampaignAdInfo,
    TextAdInfo,
    TravelAdInfo,
    VideoAdInfo,
    VideoBumperInStreamAdInfo,
    VideoNonSkippableInStreamAdInfo,
    VideoOutstreamAdInfo,
    VideoResponsiveAdInfo,
    VideoTrueViewInStreamAdInfo,
    YouTubeAudioAdInfo,
)
from .additional_application_info import (
    AdditionalApplicationInfo,
)
from .asset_policy import (
    AdAssetPolicySummary,
    AssetDisapproved,
    AssetLinkPrimaryStatusDetails,
)
from .asset_set_types import (
    BusinessProfileBusinessNameFilter,
    BusinessProfileLocationGroup,
    BusinessProfileLocationSet,
    ChainFilter,
    ChainLocationGroup,
    ChainSet,
    DynamicBusinessProfileLocationGroupFilter,
    LocationSet,
    MapsLocationInfo,
    MapsLocationSet,
)
from .asset_types import (
    AppDeepLinkAsset,
    BookOnGoogleAsset,
    BusinessMessageAsset,
    BusinessMessageCallToActionInfo,
    BusinessProfileLocation,
    CallAsset,
    CalloutAsset,
    CallToActionAsset,
    DemandGenCarouselCardAsset,
    DynamicCustomAsset,
    DynamicEducationAsset,
    DynamicFlightsAsset,
    DynamicHotelsAndRentalsAsset,
    DynamicJobsAsset,
    DynamicLocalAsset,
    DynamicRealEstateAsset,
    DynamicTravelAsset,
    HotelCalloutAsset,
    HotelPropertyAsset,
    ImageAsset,
    ImageDimension,
    LeadFormAsset,
    LeadFormCustomQuestionField,
    LeadFormDeliveryMethod,
    LeadFormField,
    LeadFormSingleChoiceAnswers,
    LocationAsset,
    MediaBundleAsset,
    MobileAppAsset,
    PageFeedAsset,
    PriceAsset,
    PriceOffering,
    PromotionAsset,
    SitelinkAsset,
    StructuredSnippetAsset,
    TextAsset,
    WebhookDelivery,
    WhatsappBusinessMessageInfo,
    YoutubeVideoAsset,
)
from .asset_usage import (
    AssetUsage,
)
from .audience_insights_attribute import (
    AudienceInsightsAttribute,
    AudienceInsightsAttributeMetadata,
    AudienceInsightsCategory,
    AudienceInsightsEntity,
    AudienceInsightsLineup,
    AudienceInsightsTopic,
    KnowledgeGraphAttributeMetadata,
    LineupAttributeMetadata,
    LocationAttributeMetadata,
    UserInterestAttributeMetadata,
    YouTubeChannelAttributeMetadata,
    YouTubeVideoAttributeMetadata,
)
from .audiences import (
    AgeDimension,
    AgeSegment,
    AudienceDimension,
    AudienceExclusionDimension,
    AudienceSegment,
    AudienceSegmentDimension,
    CustomAudienceSegment,
    DetailedDemographicSegment,
    ExclusionSegment,
    GenderDimension,
    HouseholdIncomeDimension,
    LifeEventSegment,
    ParentalStatusDimension,
    UserInterestSegment,
    UserListSegment,
)
from .bidding import (
    Commission,
    EnhancedCpc,
    FixedCpm,
    FixedCpmTargetFrequencyGoalInfo,
    ManualCpa,
    ManualCpc,
    ManualCpm,
    ManualCpv,
    MaximizeConversions,
    MaximizeConversionValue,
    PercentCpc,
    TargetCpa,
    TargetCpm,
    TargetCpmTargetFrequencyGoal,
    TargetCpv,
    TargetImpressionShare,
    TargetRoas,
    TargetSpend,
)
from .click_location import (
    ClickLocation,
)
from .consent import (
    Consent,
)
from .criteria import (
    ActivityCityInfo,
    ActivityCountryInfo,
    ActivityIdInfo,
    ActivityRatingInfo,
    ActivityStateInfo,
    AddressInfo,
    AdScheduleInfo,
    AgeRangeInfo,
    AppPaymentModelInfo,
    AudienceInfo,
    BrandInfo,
    BrandListInfo,
    CarrierInfo,
    CombinedAudienceInfo,
    ContentLabelInfo,
    CustomAffinityInfo,
    CustomAudienceInfo,
    CustomIntentInfo,
    DeviceInfo,
    GenderInfo,
    GeoPointInfo,
    HotelAdvanceBookingWindowInfo,
    HotelCheckInDateRangeInfo,
    HotelCheckInDayInfo,
    HotelCityInfo,
    HotelClassInfo,
    HotelCountryRegionInfo,
    HotelDateSelectionTypeInfo,
    HotelIdInfo,
    HotelLengthOfStayInfo,
    HotelStateInfo,
    IncomeRangeInfo,
    InteractionTypeInfo,
    IpBlockInfo,
    KeywordInfo,
    KeywordThemeInfo,
    LanguageInfo,
    ListingDimensionInfo,
    ListingDimensionPath,
    ListingGroupInfo,
    ListingScopeInfo,
    LocalServiceIdInfo,
    LocationGroupInfo,
    LocationInfo,
    MobileAppCategoryInfo,
    MobileApplicationInfo,
    MobileDeviceInfo,
    NegativeKeywordListInfo,
    OperatingSystemVersionInfo,
    ParentalStatusInfo,
    PlacementInfo,
    ProductBrandInfo,
    ProductCategoryInfo,
    ProductChannelExclusivityInfo,
    ProductChannelInfo,
    ProductConditionInfo,
    ProductCustomAttributeInfo,
    ProductGroupingInfo,
    ProductItemIdInfo,
    ProductLabelsInfo,
    ProductLegacyConditionInfo,
    ProductTypeFullInfo,
    ProductTypeInfo,
    ProximityInfo,
    SearchThemeInfo,
    TopicInfo,
    UnknownListingDimensionInfo,
    UserInterestInfo,
    UserListInfo,
    WebpageConditionInfo,
    WebpageInfo,
    WebpageListInfo,
    WebpageSampleInfo,
    YouTubeChannelInfo,
    YouTubeVideoInfo,
)
from .criterion_category_availability import (
    CriterionCategoryAvailability,
    CriterionCategoryChannelAvailability,
    CriterionCategoryLocaleAvailability,
)
from .custom_parameter import (
    CustomParameter,
)
from .customizer_value import (
    CustomizerValue,
)
from .dates import (
    DateRange,
    YearMonth,
    YearMonthRange,
)
from .extensions import (
    CallFeedItem,
    CalloutFeedItem,
    SitelinkFeedItem,
)
from .feed_common import (
    Money,
)
from .final_app_url import (
    FinalAppUrl,
)
from .frequency_cap import (
    FrequencyCapEntry,
    FrequencyCapKey,
)
from .keyword_plan_common import (
    ConceptGroup,
    HistoricalMetricsOptions,
    KeywordAnnotations,
    KeywordConcept,
    KeywordPlanAggregateMetricResults,
    KeywordPlanAggregateMetrics,
    KeywordPlanDeviceSearches,
    KeywordPlanHistoricalMetrics,
    MonthlySearchVolume,
)
from .lifecycle_goals import (
    LifecycleGoalValueSettings,
)
from .local_services import (
    LocalServicesDocumentReadOnly,
)
from .metric_goal import (
    MetricGoal,
)
from .metrics import (
    Metrics,
    SearchVolumeRange,
)
from .offline_user_data import (
    CustomerMatchUserListMetadata,
    EventAttribute,
    EventItemAttribute,
    ItemAttribute,
    OfflineUserAddressInfo,
    ShoppingLoyalty,
    StoreAttribute,
    StoreSalesMetadata,
    StoreSalesThirdPartyMetadata,
    TransactionAttribute,
    UserAttribute,
    UserData,
    UserIdentifier,
)
from .policy import (
    PolicyTopicConstraint,
    PolicyTopicEntry,
    PolicyTopicEvidence,
    PolicyValidationParameter,
    PolicyViolationKey,
)
from .policy_summary import (
    PolicySummary,
)
from .real_time_bidding_setting import (
    RealTimeBiddingSetting,
)
from .segments import (
    AssetInteractionTarget,
    BudgetCampaignAssociationStatus,
    Keyword,
    Segments,
    SkAdNetworkSourceApp,
)
from .simulation import (
    BudgetSimulationPoint,
    BudgetSimulationPointList,
    CpcBidSimulationPoint,
    CpcBidSimulationPointList,
    CpvBidSimulationPoint,
    CpvBidSimulationPointList,
    PercentCpcBidSimulationPoint,
    PercentCpcBidSimulationPointList,
    TargetCpaSimulationPoint,
    TargetCpaSimulationPointList,
    TargetImpressionShareSimulationPoint,
    TargetImpressionShareSimulationPointList,
    TargetRoasSimulationPoint,
    TargetRoasSimulationPointList,
)
from .tag_snippet import (
    TagSnippet,
)
from .targeting_setting import (
    TargetingSetting,
    TargetRestriction,
    TargetRestrictionOperation,
)
from .text_label import (
    TextLabel,
)
from .url_collection import (
    UrlCollection,
)
from .user_lists import (
    BasicUserListInfo,
    CrmBasedUserListInfo,
    FlexibleRuleOperandInfo,
    FlexibleRuleUserListInfo,
    LogicalUserListInfo,
    LogicalUserListOperandInfo,
    LookalikeUserListInfo,
    RuleBasedUserListInfo,
    SimilarUserListInfo,
    UserListActionInfo,
    UserListDateRuleItemInfo,
    UserListLogicalRuleInfo,
    UserListNumberRuleItemInfo,
    UserListRuleInfo,
    UserListRuleItemGroupInfo,
    UserListRuleItemInfo,
    UserListStringRuleItemInfo,
)
from .value import (
    Value,
)

__all__ = (
    "AdAppDeepLinkAsset",
    "AdCallToActionAsset",
    "AdDemandGenCarouselCardAsset",
    "AdImageAsset",
    "AdMediaBundleAsset",
    "AdTextAsset",
    "AdVideoAsset",
    "AdVideoAssetInfo",
    "AdVideoAssetInventoryPreferences",
    "AppAdInfo",
    "AppEngagementAdInfo",
    "AppPreRegistrationAdInfo",
    "CallAdInfo",
    "DemandGenCarouselAdInfo",
    "DemandGenMultiAssetAdInfo",
    "DemandGenProductAdInfo",
    "DemandGenVideoResponsiveAdInfo",
    "DisplayUploadAdInfo",
    "ExpandedDynamicSearchAdInfo",
    "ExpandedTextAdInfo",
    "HotelAdInfo",
    "ImageAdInfo",
    "InFeedVideoAdInfo",
    "LegacyAppInstallAdInfo",
    "LegacyResponsiveDisplayAdInfo",
    "LocalAdInfo",
    "ResponsiveDisplayAdControlSpec",
    "ResponsiveDisplayAdInfo",
    "ResponsiveSearchAdInfo",
    "ShoppingComparisonListingAdInfo",
    "ShoppingProductAdInfo",
    "ShoppingSmartAdInfo",
    "SmartCampaignAdInfo",
    "TextAdInfo",
    "TravelAdInfo",
    "VideoAdInfo",
    "VideoBumperInStreamAdInfo",
    "VideoNonSkippableInStreamAdInfo",
    "VideoOutstreamAdInfo",
    "VideoResponsiveAdInfo",
    "VideoTrueViewInStreamAdInfo",
    "YouTubeAudioAdInfo",
    "AdditionalApplicationInfo",
    "AdAssetPolicySummary",
    "AssetDisapproved",
    "AssetLinkPrimaryStatusDetails",
    "BusinessProfileBusinessNameFilter",
    "BusinessProfileLocationGroup",
    "BusinessProfileLocationSet",
    "ChainFilter",
    "ChainLocationGroup",
    "ChainSet",
    "DynamicBusinessProfileLocationGroupFilter",
    "LocationSet",
    "MapsLocationInfo",
    "MapsLocationSet",
    "AppDeepLinkAsset",
    "BookOnGoogleAsset",
    "BusinessMessageAsset",
    "BusinessMessageCallToActionInfo",
    "BusinessProfileLocation",
    "CallAsset",
    "CalloutAsset",
    "CallToActionAsset",
    "DemandGenCarouselCardAsset",
    "DynamicCustomAsset",
    "DynamicEducationAsset",
    "DynamicFlightsAsset",
    "DynamicHotelsAndRentalsAsset",
    "DynamicJobsAsset",
    "DynamicLocalAsset",
    "DynamicRealEstateAsset",
    "DynamicTravelAsset",
    "HotelCalloutAsset",
    "HotelPropertyAsset",
    "ImageAsset",
    "ImageDimension",
    "LeadFormAsset",
    "LeadFormCustomQuestionField",
    "LeadFormDeliveryMethod",
    "LeadFormField",
    "LeadFormSingleChoiceAnswers",
    "LocationAsset",
    "MediaBundleAsset",
    "MobileAppAsset",
    "PageFeedAsset",
    "PriceAsset",
    "PriceOffering",
    "PromotionAsset",
    "SitelinkAsset",
    "StructuredSnippetAsset",
    "TextAsset",
    "WebhookDelivery",
    "WhatsappBusinessMessageInfo",
    "YoutubeVideoAsset",
    "AssetUsage",
    "AudienceInsightsAttribute",
    "AudienceInsightsAttributeMetadata",
    "AudienceInsightsCategory",
    "AudienceInsightsEntity",
    "AudienceInsightsLineup",
    "AudienceInsightsTopic",
    "KnowledgeGraphAttributeMetadata",
    "LineupAttributeMetadata",
    "LocationAttributeMetadata",
    "UserInterestAttributeMetadata",
    "YouTubeChannelAttributeMetadata",
    "YouTubeVideoAttributeMetadata",
    "AgeDimension",
    "AgeSegment",
    "AudienceDimension",
    "AudienceExclusionDimension",
    "AudienceSegment",
    "AudienceSegmentDimension",
    "CustomAudienceSegment",
    "DetailedDemographicSegment",
    "ExclusionSegment",
    "GenderDimension",
    "HouseholdIncomeDimension",
    "LifeEventSegment",
    "ParentalStatusDimension",
    "UserInterestSegment",
    "UserListSegment",
    "Commission",
    "EnhancedCpc",
    "FixedCpm",
    "FixedCpmTargetFrequencyGoalInfo",
    "ManualCpa",
    "ManualCpc",
    "ManualCpm",
    "ManualCpv",
    "MaximizeConversions",
    "MaximizeConversionValue",
    "PercentCpc",
    "TargetCpa",
    "TargetCpm",
    "TargetCpmTargetFrequencyGoal",
    "TargetCpv",
    "TargetImpressionShare",
    "TargetRoas",
    "TargetSpend",
    "ClickLocation",
    "Consent",
    "ActivityCityInfo",
    "ActivityCountryInfo",
    "ActivityIdInfo",
    "ActivityRatingInfo",
    "ActivityStateInfo",
    "AddressInfo",
    "AdScheduleInfo",
    "AgeRangeInfo",
    "AppPaymentModelInfo",
    "AudienceInfo",
    "BrandInfo",
    "BrandListInfo",
    "CarrierInfo",
    "CombinedAudienceInfo",
    "ContentLabelInfo",
    "CustomAffinityInfo",
    "CustomAudienceInfo",
    "CustomIntentInfo",
    "DeviceInfo",
    "GenderInfo",
    "GeoPointInfo",
    "HotelAdvanceBookingWindowInfo",
    "HotelCheckInDateRangeInfo",
    "HotelCheckInDayInfo",
    "HotelCityInfo",
    "HotelClassInfo",
    "HotelCountryRegionInfo",
    "HotelDateSelectionTypeInfo",
    "HotelIdInfo",
    "HotelLengthOfStayInfo",
    "HotelStateInfo",
    "IncomeRangeInfo",
    "InteractionTypeInfo",
    "IpBlockInfo",
    "KeywordInfo",
    "KeywordThemeInfo",
    "LanguageInfo",
    "ListingDimensionInfo",
    "ListingDimensionPath",
    "ListingGroupInfo",
    "ListingScopeInfo",
    "LocalServiceIdInfo",
    "LocationGroupInfo",
    "LocationInfo",
    "MobileAppCategoryInfo",
    "MobileApplicationInfo",
    "MobileDeviceInfo",
    "NegativeKeywordListInfo",
    "OperatingSystemVersionInfo",
    "ParentalStatusInfo",
    "PlacementInfo",
    "ProductBrandInfo",
    "ProductCategoryInfo",
    "ProductChannelExclusivityInfo",
    "ProductChannelInfo",
    "ProductConditionInfo",
    "ProductCustomAttributeInfo",
    "ProductGroupingInfo",
    "ProductItemIdInfo",
    "ProductLabelsInfo",
    "ProductLegacyConditionInfo",
    "ProductTypeFullInfo",
    "ProductTypeInfo",
    "ProximityInfo",
    "SearchThemeInfo",
    "TopicInfo",
    "UnknownListingDimensionInfo",
    "UserInterestInfo",
    "UserListInfo",
    "WebpageConditionInfo",
    "WebpageInfo",
    "WebpageListInfo",
    "WebpageSampleInfo",
    "YouTubeChannelInfo",
    "YouTubeVideoInfo",
    "CriterionCategoryAvailability",
    "CriterionCategoryChannelAvailability",
    "CriterionCategoryLocaleAvailability",
    "CustomParameter",
    "CustomizerValue",
    "DateRange",
    "YearMonth",
    "YearMonthRange",
    "CallFeedItem",
    "CalloutFeedItem",
    "SitelinkFeedItem",
    "Money",
    "FinalAppUrl",
    "FrequencyCapEntry",
    "FrequencyCapKey",
    "ConceptGroup",
    "HistoricalMetricsOptions",
    "KeywordAnnotations",
    "KeywordConcept",
    "KeywordPlanAggregateMetricResults",
    "KeywordPlanAggregateMetrics",
    "KeywordPlanDeviceSearches",
    "KeywordPlanHistoricalMetrics",
    "MonthlySearchVolume",
    "LifecycleGoalValueSettings",
    "LocalServicesDocumentReadOnly",
    "MetricGoal",
    "Metrics",
    "SearchVolumeRange",
    "CustomerMatchUserListMetadata",
    "EventAttribute",
    "EventItemAttribute",
    "ItemAttribute",
    "OfflineUserAddressInfo",
    "ShoppingLoyalty",
    "StoreAttribute",
    "StoreSalesMetadata",
    "StoreSalesThirdPartyMetadata",
    "TransactionAttribute",
    "UserAttribute",
    "UserData",
    "UserIdentifier",
    "PolicyTopicConstraint",
    "PolicyTopicEntry",
    "PolicyTopicEvidence",
    "PolicyValidationParameter",
    "PolicyViolationKey",
    "PolicySummary",
    "RealTimeBiddingSetting",
    "AssetInteractionTarget",
    "BudgetCampaignAssociationStatus",
    "Keyword",
    "Segments",
    "SkAdNetworkSourceApp",
    "BudgetSimulationPoint",
    "BudgetSimulationPointList",
    "CpcBidSimulationPoint",
    "CpcBidSimulationPointList",
    "CpvBidSimulationPoint",
    "CpvBidSimulationPointList",
    "PercentCpcBidSimulationPoint",
    "PercentCpcBidSimulationPointList",
    "TargetCpaSimulationPoint",
    "TargetCpaSimulationPointList",
    "TargetImpressionShareSimulationPoint",
    "TargetImpressionShareSimulationPointList",
    "TargetRoasSimulationPoint",
    "TargetRoasSimulationPointList",
    "TagSnippet",
    "TargetingSetting",
    "TargetRestriction",
    "TargetRestrictionOperation",
    "TextLabel",
    "UrlCollection",
    "BasicUserListInfo",
    "CrmBasedUserListInfo",
    "FlexibleRuleOperandInfo",
    "FlexibleRuleUserListInfo",
    "LogicalUserListInfo",
    "LogicalUserListOperandInfo",
    "LookalikeUserListInfo",
    "RuleBasedUserListInfo",
    "SimilarUserListInfo",
    "UserListActionInfo",
    "UserListDateRuleItemInfo",
    "UserListLogicalRuleInfo",
    "UserListNumberRuleItemInfo",
    "UserListRuleInfo",
    "UserListRuleItemGroupInfo",
    "UserListRuleItemInfo",
    "UserListStringRuleItemInfo",
    "Value",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.resources",
    marshal="google.ads.googleads.v21",
    manifest={
        "CurrencyConstant",
    },
)


class CurrencyConstant(proto.Message):
    r"""A currency constant.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Output only. The resource name of the currency constant.
            Currency constant resource names have the form:

            ``currencyConstants/{code}``
        code (str):
            Output only. ISO 4217 three-letter currency
            code, for example, "USD".

            This field is a member of `oneof`_ ``_code``.
        name (str):
            Output only. Full English name of the
            currency.

            This field is a member of `oneof`_ ``_name``.
        symbol (str):
            Output only. Standard symbol for describing
            this currency, for example, '$' for US Dollars.

            This field is a member of `oneof`_ ``_symbol``.
        billable_unit_micros (int):
            Output only. The billable unit for this
            currency. Billed amounts should be multiples of
            this value.

            This field is a member of `oneof`_ ``_billable_unit_micros``.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    code: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    name: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    symbol: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    billable_unit_micros: int = proto.Field(
        proto.INT64,
        number=9,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.enums",
    marshal="google.ads.googleads.v21",
    manifest={
        "AdGroupCriterionPrimaryStatusReasonEnum",
    },
)


class AdGroupCriterionPrimaryStatusReasonEnum(proto.Message):
    r"""Container for enum describing possible ad group criterion
    primary status reasons.

    """

    class AdGroupCriterionPrimaryStatusReason(proto.Enum):
        r"""Enum describing the possible Ad Group Criterion primary
        status reasons. Provides insight into why an Ad Group Criterion
        is not serving or not serving optimally. These reasons are
        aggregated to determine an overall Ad Group Criterion primary
        status.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents
                unknown value in this version.
            CAMPAIGN_PENDING (2):
                The user-specified time for this campaign to
                start is in the future. Contributes to
                AdGroupCriterionPrimaryStatus.PENDING.
            CAMPAIGN_CRITERION_NEGATIVE (3):
                The ad group criterion is overridden by negative campaign
                criterion. Contributes to
                AdGroupCriterionPrimaryStatus.NOT_ELIGIBLE.
            CAMPAIGN_PAUSED (4):
                The user-specified campaign status is paused.
                Contributes to
                AdGroupCriterionPrimaryStatus.PAUSED.
            CAMPAIGN_REMOVED (5):
                The user-specified campaign status is
                removed. Contributes to
                AdGroupCriterionPrimaryStatus.REMOVED.
            CAMPAIGN_ENDED (6):
                The user-specified time for this campaign to
                end has passed. Contributes to
                AdGroupCriterionPrimaryStatus.ENDED.
            AD_GROUP_PAUSED (7):
                The user-specified ad group status is paused.
                Contributes to
                AdGroupCriterionPrimaryStatus.PAUSED.
            AD_GROUP_REMOVED (8):
                The user-specified ad group status is
                removed. Contributes to
                AdGroupCriterionPrimaryStatus.REMOVED.
            AD_GROUP_CRITERION_DISAPPROVED (9):
                The ad group criterion is disapproved by the ads approval
                system. Contributes to
                AdGroupCriterionPrimaryStatus.NOT_ELIGIBLE.
            AD_GROUP_CRITERION_RARELY_SERVED (10):
                The ad group criterion is rarely served. Contributes to
                AdGroupCriterionPrimaryStatus.NOT_ELIGIBLE.
            AD_GROUP_CRITERION_LOW_QUALITY (11):
                The ad group criterion has a low quality
                score. Contributes to
                AdGroupCriterionPrimaryStatus.LIMITED.
            AD_GROUP_CRITERION_UNDER_REVIEW (12):
                The ad group criterion is under review.
                Contributes to
                AdGroupCriterionPrimaryStatus.PENDING.
            AD_GROUP_CRITERION_PENDING_REVIEW (13):
                The ad group criterion is pending review. Contributes to
                AdGroupCriterionPrimaryStatus.NOT_ELIGIBLE.
            AD_GROUP_CRITERION_BELOW_FIRST_PAGE_BID (14):
                The ad group criterion's bid is below the
                value necessary to serve on the first page.
                Contributes to
                AdGroupCriterionPrimaryStatus.LIMITED.
            AD_GROUP_CRITERION_NEGATIVE (15):
                The ad group criterion is negative. Contributes to
                AdGroupCriterionPrimaryStatus.NOT_ELIGIBLE.
            AD_GROUP_CRITERION_RESTRICTED (16):
                The ad group criterion is restricted. Contributes to
                AdGroupCriterionPrimaryStatus.NOT_ELIGIBLE.
            AD_GROUP_CRITERION_PAUSED (17):
                The user-specified ad group criterion status
                is paused. Contributes to
                AdGroupCriterionPrimaryStatus.PAUSED.
            AD_GROUP_CRITERION_PAUSED_DUE_TO_LOW_ACTIVITY (18):
                The ad group criterion has been paused due to
                prolonged low activity in serving. Contributes
                to AdGroupCriterionPrimaryStatus.PAUSED.
            AD_GROUP_CRITERION_REMOVED (19):
                The user-specified ad group criterion status
                is removed. Contributes to
                AdGroupCriterionPrimaryStatus.REMOVED.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        CAMPAIGN_PENDING = 2
        CAMPAIGN_CRITERION_NEGATIVE = 3
        CAMPAIGN_PAUSED = 4
        CAMPAIGN_REMOVED = 5
        CAMPAIGN_ENDED = 6
        AD_GROUP_PAUSED = 7
        AD_GROUP_REMOVED = 8
        AD_GROUP_CRITERION_DISAPPROVED = 9
        AD_GROUP_CRITERION_RARELY_SERVED = 10
        AD_GROUP_CRITERION_LOW_QUALITY = 11
        AD_GROUP_CRITERION_UNDER_REVIEW = 12
        AD_GROUP_CRITERION_PENDING_REVIEW = 13
        AD_GROUP_CRITERION_BELOW_FIRST_PAGE_BID = 14
        AD_GROUP_CRITERION_NEGATIVE = 15
        AD_GROUP_CRITERION_RESTRICTED = 16
        AD_GROUP_CRITERION_PAUSED = 17
        AD_GROUP_CRITERION_PAUSED_DUE_TO_LOW_ACTIVITY = 18
        AD_GROUP_CRITERION_REMOVED = 19


__all__ = tuple(sorted(__protobuf__.manifest))
